Documentation
¶
Overview ¶
Package greet implements greeting functions.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fhelloln ¶
Fhelloln formats and prints a greeting string to given writer. See fmt.Fprintln.
Example ¶
package main
import (
"os"
"codeberg.org/kurth4cker/go-sample/greet"
)
func main() {
greet.Fhelloln(os.Stdout, "kurth4cker")
}
Output: hello kurth4cker
func Helloln ¶
func Helloln(user string)
Helloln writes formatted greeting and a newline to os.Stdout.
Example ¶
package main
import (
"codeberg.org/kurth4cker/go-sample/greet"
)
func main() {
greet.Helloln("Gopher")
}
Output: hello Gopher
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.